TalkerHttpLogger class

Inheritance
  • Object
  • InterceptorContract
  • TalkerHttpLogger

Constructors

TalkerHttpLogger({Talker? talker, TalkerHttpLoggerSettings settings = const TalkerHttpLoggerSettings(), String? addonId})

Properties

addonId → String?
Talker addon functionality addon id for creating a lot of addons
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings ↔ TalkerHttpLoggerSettings
TalkerHttpLogger settings and customization
getter/setter pair

Methods

configure({bool? enabled, LogLevel? logLevel, bool? printResponseData, bool? printResponseHeaders, bool? printResponseMessage, bool? printResponseTime, bool? printErrorData, bool? printErrorHeaders, bool? printErrorMessage, bool? printRequestData, bool? printRequestHeaders, bool? printRequestCurl, AnsiPen? requestPen, AnsiPen? responsePen, AnsiPen? errorPen, RequestFilter? requestFilter, ResponseFilter? responseFilter, ResponseFilter? errorFilter, Set<String>? hiddenHeaders}) → void
Method to update settings of TalkerHttpLogger
interceptRequest({required BaseRequest request}) → Future<BaseRequest>
override
interceptResponse({required BaseResponse response}) → Future<BaseResponse>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldInterceptRequest() → FutureOr<bool>
inherited
shouldInterceptResponse() → FutureOr<bool>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

kLogsTimeStamp → const String