TalkerHttpLoggerSettings class

Constructors

TalkerHttpLoggerSettings({bool enabled = true, LogLevel logLevel = LogLevel.debug, bool printResponseData = true, bool printResponseHeaders = false, bool printResponseMessage = true, bool printResponseRedirects = false, bool printResponseTime = false, bool printErrorData = true, bool printErrorHeaders = true, bool printErrorMessage = true, bool printRequestData = true, bool printRequestHeaders = false, bool printRequestCurl = false, Set<String> hiddenHeaders = const <String>{}, TalkerJsonFormatter jsonFormatter = const TalkerJsonFormatter(), AnsiPen? requestPen, AnsiPen? responsePen, AnsiPen? errorPen, RequestFilter? requestFilter, ResponseFilter? responseFilter, ResponseFilter? errorFilter})
const

Properties

enabled → bool
Print Http logger if true
final
errorFilter → ResponseFilter?
For error filtering. You can add your custom logic to log only specific HTTP error Response.
final
errorPen → AnsiPen?
Field to set custom http error console logs color
final
hashCode → int
The hash code for this object.
no setterinherited
hiddenHeaders → Set<String>
Header values for the specified keys in the Set will be replaced with *****. Case insensitive
final
jsonFormatter → TalkerJsonFormatter
JSON formatter for converting data to pretty string. Use TalkerJsonFormatter for default formatting, TalkerJsonFormatter(stripQuotes: true) to strip quotes, or TalkerJsonFormatter.custom(fn) for custom formatting.
final
logLevel → LogLevel
final
printErrorData → bool
Print error.response.data if true
final
printErrorHeaders → bool
Print error.response.headers if true
final
printErrorMessage → bool
Print error.message if true
final
printRequestCurl → bool
Prints a curl request equivalent of the network call if true
final
printRequestData → bool
Print request.data if true
final
printRequestHeaders → bool
Print request.headers if true
final
printResponseData → bool
Print response.data if true
final
printResponseHeaders → bool
Print response.headers if true
final
printResponseMessage → bool
Print response.statusMessage if true
final
printResponseRedirects → bool
Print response.redirects if true
final
printResponseTime → bool
Print response time if true
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
requestFilter → RequestFilter?
For request filtering. You can add your custom logic to log only specific HTTP requests Request.
final
requestPen → AnsiPen?
Field to set custom http request console logs color
final
responseFilter → ResponseFilter?
For response filtering. You can add your custom logic to log only specific HTTP responses Response.
final
responsePen → AnsiPen?
Field to set custom http response console logs color
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

copyWith({bool? enabled, LogLevel? logLevel, bool? printResponseData, bool? printResponseHeaders, bool? printResponseMessage, bool? printResponseTime, bool? printErrorData, bool? printErrorHeaders, bool? printErrorMessage, bool? printRequestData, bool? printRequestHeaders, bool? printRequestCurl, AnsiPen? requestPen, AnsiPen? responsePen, AnsiPen? errorPen, RequestFilter? requestFilter, ResponseFilter? responseFilter, ResponseFilter? errorFilter, Set<String>? hiddenHeaders, TalkerJsonFormatter? jsonFormatter}) → TalkerHttpLoggerSettings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited